Option Strict Off
Option Explicit On
Module Hardware
	' **********************************************************
	' ***         Module with IO1388-DLL Functions           ***
	' **********************************************************
    ' ***       (c) 2007 by ERMA - Electronic GmbH           ***
	' **********************************************************
    ' ***  programmed: 12.07.2007 Frank Jessen Dipl.Ing.(FH) ***
	' **********************************************************
	
	' **********************************************************
	' *** Error codes used by IO1388_GetLastError            ***
	' **********************************************************
	Public Const IO1388_ERR_OK As Short = 0
	Public Const IO1388_ERR_ALREADYOPEN As Short = 1
	Public Const IO1388_ERR_NOTOPEN As Short = 2
	Public Const IO1388_ERR_NOCARD As Short = 3
	Public Const IO1388_ERR_NOADDRESS As Short = 4
	Public Const IO1388_ERR_NOVALUE As Short = 5
	Public Const IO1388_ERR_WRONGMODE As Short = 6
	Public Const IO1388_ERR_VXDNOTFOUND As Short = 7
	Public Const IO1388_ERR_DRVNOTFOUND As Short = 7
	Public Const IO1388_ERR_INTERNALERROR As Short = 8
	Public Const IO1388_ERR_FUNCDISABLED As Short = 9
	Public Const IO1388_ERR_WRONGVALUE As Short = 10
	Public Const IO1388_ERR_DEVICERUNNING As Short = 11
	Public Const IO1388_ERR_DEVICESTOPPED As Short = 12

    ' **********************************************************
    ' ***  Flags                                             ***
    ' **********************************************************/
    Public Const IO1388_RUNNING As Short = &H1
    Public Const IO1388_IOINT As Short = &H2
    Public Const IO1388_TMINT As Short = &H4
    Public Const IO1388_WDINT As Short = &H8
    Public Const IO1388_VALUE As Short = &H10
    Public Const IO1388_FIFOOV As Short = &H20

    ' **********************************************************
    ' ***  Interrupt enable                                  ***
    ' **********************************************************/
    Public Const IO1388_GLOBAL_IRQ_ENABLE As Long = &H80000000
    Public Const IO1388_IO_IRQ_ENABLE As Long = &H40000000
    Public Const IO1388_WATCHDOG_IRQ_ENABLE As Long = &H20000000
    Public Const IO1388_TIMER_IRQ_ENABLE As Long = &H10000000

    ' **********************************************************
    ' *** Include all DLL-functions                          ***
    ' **********************************************************

    ' **********************************************************
    ' *** This function has to be called once at the begin of***
    ' *** the program!                                       ***
    ' *** Return Parameter:                                  ***
    ' ***     0 = Error                                      ***
    ' ***   255 = O.K.                                       ***
    ' **********************************************************
	Public Declare Function IO1388_InitDriver Lib "IO1388.DLL"  Alias "_IO1388_InitDriver@0"() As Byte
	
	' **********************************************************
	' *** This function has to be called once at the end of  ***
	' *** the program!                                       ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_DeInitDriver Lib "IO1388.DLL"  Alias "_IO1388_DeInitDriver@0"() As Byte
	
	' **********************************************************
	' *** This function returns the number of IO1388-Cards   ***
	' *** installed on the PC                                ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** CardCount = Number of installed cards              ***
	' **********************************************************
	Public Declare Function IO1388_GetCardCount Lib "IO1388.DLL"  Alias "_IO1388_GetCardCount@4"(ByRef CardCount As Byte) As Byte
	
	' **********************************************************
	' *** This function returns the serial number of a card  ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** CardCount = Number of installed cards              ***
	' **********************************************************
	Public Declare Function IO1388_GetCardNumber Lib "IO1388.DLL"  Alias "_IO1388_GetCardNumber@8"(ByVal CardNr As Byte, ByRef Number As Integer) As Byte
	
	' **********************************************************
	' *** This function returns the error code of the last   ***
	' *** called DLL-function                                ***
	' *** Return Parameter:                                  ***
	' **********************************************************
	Public Declare Function IO1388_GetLastError Lib "IO1388.DLL"  Alias "_IO1388_GetLastError@0"() As Short
	
	' **********************************************************
	' *** This function sets the outputs                     ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' ***  Value  = state for the outputs                    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_WriteOutputs Lib "IO1388.DLL"  Alias "_IO1388_WriteOutputs@8"(ByVal CardNr As Byte, ByVal Value As Integer) As Byte
	
	' **********************************************************
	' *** This function rereads the outputs                  ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** Value = state of the outputs                       ***
	' **********************************************************
	Public Declare Function IO1388_ReadOutputs Lib "IO1388.DLL"  Alias "_IO1388_ReadOutputs@8"(ByVal CardNr As Byte, ByRef Value As Integer) As Byte
	
	' **********************************************************
	' *** This function reads the inputs                     ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** Value = state of the inputs                        ***
	' **********************************************************
	Public Declare Function IO1388_ReadInputs Lib "IO1388.DLL"  Alias "_IO1388_ReadInputs@8"(ByVal CardNr As Byte, ByRef Value As Integer) As Byte
	
	' **********************************************************
	' *** This function reads the interrupt enables for the  ***
	' *** rising edge of the inputs                          ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** Value = interrupt enables for rising edge          ***
	' **********************************************************
	Public Declare Function IO1388_ReadIntRise Lib "IO1388.DLL"  Alias "_IO1388_ReadIntRise@8"(ByVal CardNr As Byte, ByRef Value As Integer) As Byte
	
	' **********************************************************
	' *** This function sets the interrupt enables for the   ***
	' *** rising edge for the inputs                         ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' ***  Value  = interrupt enables for the rising edge    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_WriteIntRise Lib "IO1388.DLL"  Alias "_IO1388_WriteIntRise@8"(ByVal CardNr As Byte, ByVal Value As Integer) As Byte
	
	' **********************************************************
	' *** This function reads the interrupt enables for the  ***
	' *** falling edge of the inputs                         ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** Value = interrupt enables for falling edge         ***
	' **********************************************************
	Public Declare Function IO1388_ReadIntFall Lib "IO1388.DLL"  Alias "_IO1388_ReadIntFall@8"(ByVal CardNr As Byte, ByRef Value As Integer) As Byte
	
	' **********************************************************
	' *** This function sets the interrupt enables for the   ***
	' *** falling edge for the inputs                        ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' ***  Value  = interrupt enables for the falling edge   ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_WriteIntFall Lib "IO1388.DLL"  Alias "_IO1388_WriteIntFall@8"(ByVal CardNr As Byte, ByVal Value As Integer) As Byte
	
	' **********************************************************
	' *** This function reads the timer/status register      ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** Value = timer/status value                         ***
	' **********************************************************
	Public Declare Function IO1388_ReadTimerStatus Lib "IO1388.DLL"  Alias "_IO1388_ReadTimerStatus@8"(ByVal CardNr As Byte, ByRef Value As Integer) As Byte
	
	' **********************************************************
	' *** This function sets the timer/status register       ***
	' *** Input Parameter:                                   ***
	' ***  CardNr = zero-based number of the desired card    ***
	' ***  Value  = new timer/status value                   ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_WriteTimerStatus Lib "IO1388.DLL"  Alias "_IO1388_WriteTimerStatus@8"(ByVal CardNr As Byte, ByVal Value As Integer) As Byte
	
	' **********************************************************
	' *** This function reads the watchdog-timer value       ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** Value = watchdog-timer value                       ***
	' **********************************************************
	Public Declare Function IO1388_ReadWdTimer Lib "IO1388.DLL"  Alias "_IO1388_ReadWdTimer@8"(ByVal CardNr As Byte, ByRef Value As Integer) As Byte
	
	' **********************************************************
	' *** This function sets the watchdog-timer value        ***
	' ***  CardNr = zero-based number of the desired card    ***
	' ***  Value  = new watchdog-timer value                 ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_WriteWdTimer Lib "IO1388.DLL"  Alias "_IO1388_WriteWdTimer@8"(ByVal CardNr As Byte, ByVal Value As Integer) As Byte
	
	' **********************************************************
	' *** This function reads the watchdog-output value      ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** Value = watchdog-output value                      ***
	' **********************************************************
	Public Declare Function IO1388_ReadWdValue Lib "IO1388.DLL"  Alias "_IO1388_ReadWdValue@8"(ByVal CardNr As Byte, ByRef Value As Integer) As Byte
	
	' **********************************************************
	' *** This function sets the watchdog-output value       ***
	' ***  CardNr = zero-based number of the desired card    ***
	' ***  Value  = new watchdog-output value                ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_WriteWdValue Lib "IO1388.DLL"  Alias "_IO1388_WriteWdValue@8"(ByVal CardNr As Byte, ByVal Value As Integer) As Byte
	
	' **********************************************************
	' *** This function starts interrupt handling. Interrupt-***
	' *** enables has to be set by other functions.          ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_StartIRQ Lib "IO1388.DLL"  Alias "_IO1388_StartIRQ@4"(ByVal CardNr As Byte) As Byte
	
	' **********************************************************
	' *** This function stops interrupt handling. Interrupt- ***
	' *** enables has to be set/reset by other functions.    ***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' **********************************************************
	Public Declare Function IO1388_StopIRQ Lib "IO1388.DLL"  Alias "_IO1388_StopIRQ@4"(ByVal CardNr As Byte) As Byte
	
	' **********************************************************
	' *** This function reads the state of interrupt-handling***
	' ***  CardNr = zero-based number of the desired card    ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' *** Value = Flags                                      ***
	' **********************************************************
	Public Declare Function IO1388_GetIRQStatus Lib "IO1388.DLL"  Alias "_IO1388_GetIRQStatus@8"(ByVal CardNr As Byte, ByRef Value As Integer) As Byte
	
	' **********************************************************
	' *** This function reads the interrupt-handled inputs   ***
	' *** blockwise.                                         ***
	' ***  CardNr = zero-based number of the desired card    ***
	' ***  buffer = array where inputs will be saved         ***
	' ***  buffersize = size in LongInts, not Bytes!         ***
	' *** Return Parameter:                                  ***
	' ***     0 = Error                                      ***
	' ***   255 = O.K.                                       ***
	' ***     n = number of input-values copied to array     ***
	' **********************************************************
    Public Declare Function IO1388_GetIRQInputs Lib "IO1388.DLL" Alias "_IO1388_GetIRQInputs@16" (ByVal CardNr As Byte, ByRef buffer As Long, ByVal buffersize As Integer, ByRef n As Integer) As Byte
End Module