Attribute VB_Name = "Hardware"
Rem **********************************************************
Rem ***         Module with IO1388-DLL Functions           ***
Rem **********************************************************
Rem ***       (c) 2001 by ERMA - Electronic GmbH           ***
Rem **********************************************************
Rem ***  programmed: 12.05.2001 Frank Jessen Dipl.Ing.(FH) ***
Rem **********************************************************

Rem **********************************************************
Rem *** Error codes used by IO1388_GetLastError            ***
Rem **********************************************************
Public Const IO1388_ERR_OK            As Integer = 0
Public Const IO1388_ERR_ALREADYOPEN   As Integer = 1
Public Const IO1388_ERR_NOTOPEN       As Integer = 2
Public Const IO1388_ERR_NOCARD        As Integer = 3
Public Const IO1388_ERR_NOADDRESS     As Integer = 4
Public Const IO1388_ERR_NOVALUE       As Integer = 5
Public Const IO1388_ERR_WRONGMODE     As Integer = 6
Public Const IO1388_ERR_VXDNOTFOUND   As Integer = 7
Public Const IO1388_ERR_DRVNOTFOUND   As Integer = 7
Public Const IO1388_ERR_INTERNALERROR As Integer = 8
Public Const IO1388_ERR_FUNCDISABLED  As Integer = 9
Public Const IO1388_ERR_WRONGVALUE    As Integer = 10
Public Const IO1388_ERR_DEVICERUNNING As Integer = 11
Public Const IO1388_ERR_DEVICESTOPPED As Integer = 12

Rem **********************************************************
Rem *** Include all DLL-functions                          ***
Rem **********************************************************

Rem **********************************************************
Rem *** This function has to be called once at the begin of***
Rem *** the program!                                       ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_InitDriver Lib "IO1388.DLL" Alias "_IO1388_InitDriver@0" () As Byte

Rem **********************************************************
Rem *** This function has to be called once at the end of  ***
Rem *** the program!                                       ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_DeInitDriver Lib "IO1388.DLL" Alias "_IO1388_DeInitDriver@0" () As Byte

Rem **********************************************************
Rem *** This function returns the number of IO1388-Cards   ***
Rem *** installed on the PC                                ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** CardCount = Number of installed cards              ***
Rem **********************************************************
Public Declare Function IO1388_GetCardCount Lib "IO1388.DLL" Alias "_IO1388_GetCardCount@4" (ByRef CardCount As Byte) As Byte

Rem **********************************************************
Rem *** This function returns the serial number of a card  ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** CardCount = Number of installed cards              ***
Rem **********************************************************
Public Declare Function IO1388_GetCardNumber Lib "IO1388.DLL" Alias "_IO1388_GetCardNumber@8" (ByVal CardNr As Byte, ByRef Number As Long) As Byte

Rem **********************************************************
Rem *** This function returns the error code of the last   ***
Rem *** called DLL-function                                ***
Rem *** Return Parameter:                                  ***
Rem **********************************************************
Public Declare Function IO1388_GetLastError Lib "IO1388.DLL" Alias "_IO1388_GetLastError@0" () As Integer

Rem **********************************************************
Rem *** This function sets the outputs                     ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem ***  Value  = state for the outputs                    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_WriteOutputs Lib "IO1388.DLL" Alias "_IO1388_WriteOutputs@8" (ByVal CardNr As Byte, ByVal Value As Long) As Byte

Rem **********************************************************
Rem *** This function rereads the outputs                  ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** Value = state of the outputs                       ***
Rem **********************************************************
Public Declare Function IO1388_ReadOutputs Lib "IO1388.DLL" Alias "_IO1388_ReadOutputs@8" (ByVal CardNr As Byte, ByRef Value As Long) As Byte

Rem **********************************************************
Rem *** This function reads the inputs                     ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** Value = state of the inputs                        ***
Rem **********************************************************
Public Declare Function IO1388_ReadInputs Lib "IO1388.DLL" Alias "_IO1388_ReadInputs@8" (ByVal CardNr As Byte, ByRef Value As Long) As Byte

Rem **********************************************************
Rem *** This function reads the interrupt enables for the  ***
Rem *** rising edge of the inputs                          ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** Value = interrupt enables for rising edge          ***
Rem **********************************************************
Public Declare Function IO1388_ReadIntRise Lib "IO1388.DLL" Alias "_IO1388_ReadIntRise@8" (ByVal CardNr As Byte, ByRef Value As Long) As Byte

Rem **********************************************************
Rem *** This function sets the interrupt enables for the   ***
Rem *** rising edge for the inputs                         ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem ***  Value  = interrupt enables for the rising edge    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_WriteIntRise Lib "IO1388.DLL" Alias "_IO1388_WriteIntRise@8" (ByVal CardNr As Byte, ByVal Value As Long) As Byte

Rem **********************************************************
Rem *** This function reads the interrupt enables for the  ***
Rem *** falling edge of the inputs                         ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** Value = interrupt enables for falling edge         ***
Rem **********************************************************
Public Declare Function IO1388_ReadIntFall Lib "IO1388.DLL" Alias "_IO1388_ReadIntFall@8" (ByVal CardNr As Byte, ByRef Value As Long) As Byte

Rem **********************************************************
Rem *** This function sets the interrupt enables for the   ***
Rem *** falling edge for the inputs                        ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem ***  Value  = interrupt enables for the falling edge   ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_WriteIntFall Lib "IO1388.DLL" Alias "_IO1388_WriteIntFall@8" (ByVal CardNr As Byte, ByVal Value As Long) As Byte

Rem **********************************************************
Rem *** This function reads the timer/status register      ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** Value = timer/status value                         ***
Rem **********************************************************
Public Declare Function IO1388_ReadTimerStatus Lib "IO1388.DLL" Alias "_IO1388_ReadTimerStatus@8" (ByVal CardNr As Byte, ByRef Value As Long) As Byte

Rem **********************************************************
Rem *** This function sets the timer/status register       ***
Rem *** Input Parameter:                                   ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem ***  Value  = new timer/status value                   ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_WriteTimerStatus Lib "IO1388.DLL" Alias "_IO1388_WriteTimerStatus@8" (ByVal CardNr As Byte, ByVal Value As Long) As Byte

Rem **********************************************************
Rem *** This function reads the watchdog-timer value       ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** Value = watchdog-timer value                       ***
Rem **********************************************************
Public Declare Function IO1388_ReadWdTimer Lib "IO1388.DLL" Alias "_IO1388_ReadWdTimer@8" (ByVal CardNr As Byte, ByRef Value As Long) As Byte

Rem **********************************************************
Rem *** This function sets the watchdog-timer value        ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem ***  Value  = new watchdog-timer value                 ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_WriteWdTimer Lib "IO1388.DLL" Alias "_IO1388_WriteWdTimer@8" (ByVal CardNr As Byte, ByVal Value As Long) As Byte

Rem **********************************************************
Rem *** This function reads the watchdog-output value      ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** Value = watchdog-output value                      ***
Rem **********************************************************
Public Declare Function IO1388_ReadWdValue Lib "IO1388.DLL" Alias "_IO1388_ReadWdValue@8" (ByVal CardNr As Byte, ByRef Value As Long) As Byte

Rem **********************************************************
Rem *** This function sets the watchdog-output value       ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem ***  Value  = new watchdog-output value                ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_WriteWdValue Lib "IO1388.DLL" Alias "_IO1388_WriteWdValue@8" (ByVal CardNr As Byte, ByVal Value As Long) As Byte

Rem **********************************************************
Rem *** This function starts interrupt handling. Interrupt-***
Rem *** enables has to be set by other functions.          ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_StartIRQ Lib "IO1388.DLL" Alias "_IO1388_StartIRQ@4" (ByVal CardNr As Byte) As Byte

Rem **********************************************************
Rem *** This function stops interrupt handling. Interrupt- ***
Rem *** enables has to be set/reset by other functions.    ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem **********************************************************
Public Declare Function IO1388_StopIRQ Lib "IO1388.DLL" Alias "_IO1388_StopIRQ@4" (ByVal CardNr As Byte) As Byte

Rem **********************************************************
Rem *** This function reads the state of interrupt-handling***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem *** Value = Flags                                      ***
Rem **********************************************************
Public Declare Function IO1388_GetIRQStatus Lib "IO1388.DLL" Alias "_IO1388_GetIRQStatus@8" (ByVal CardNr As Byte, ByRef Value As Long) As Byte

Rem **********************************************************
Rem *** This function reads the interrupt-handled inputs   ***
Rem *** blockwise.                                         ***
Rem ***  CardNr = zero-based number of the desired card    ***
Rem ***  buffer = array where inputs will be saved         ***
Rem ***  buffersize = size in LongInts, not Bytes!         ***
Rem *** Return Parameter:                                  ***
Rem ***     0 = Error                                      ***
Rem ***   255 = O.K.                                       ***
Rem ***     n = number of input-values copied to array     ***
Rem **********************************************************
Public Declare Function IO1388_GetIRQInputs Lib "IO1388.DLL" Alias "_IO1388_GetIRQInputs@16" (ByVal CardNr As Byte, ByRef buffer() As Long, ByVal buffersize As Long, ByRef n As Long) As Byte

