unit IO1388DLL;
(**********************************************************
 ***              Unit for IO 1388-DLL                  ***
 **********************************************************
 ***       (c) 2001 by ERMA - Electronic GmbH           ***
 **********************************************************
 ***  Programmed: 16.05.2001 Frank Jessen Dipl.Ing.(FH) ***
 **********************************************************)
interface

type
  pLongInt = ^LongInt;

const
  (********************************************************
   ***  Error messages                                  ***
   ********************************************************)
  IO1388_ERR_OK            = 0;
  IO1388_ERR_ALREADYOPEN   = 1;
  IO1388_ERR_NOTOPEN       = 2;
  IO1388_ERR_NOCARD        = 3;
  IO1388_ERR_NOADDRESS     = 4;
  IO1388_ERR_NOVALUE       = 5;
  IO1388_ERR_WRONGMODE     = 6;
  IO1388_ERR_VXDNOTFOUND   = 7;
  IO1388_ERR_DRVNOTFOUND   = 7;
  IO1388_ERR_INTERNALERROR = 8;
  IO1388_ERR_FUNCDISABLED  = 9;
  IO1388_ERR_WRONGVALUE    = 10;
  IO1388_ERR_DEVICERUNNING = 11;
  IO1388_ERR_DEVICESTOPPED = 12;

  (********************************************************
   ***  Flags                                           ***
   ********************************************************)
  IO1388_RUNNING     = $0001;
  IO1388_IOINT       = $0002;
  IO1388_TMINT       = $0004;
  IO1388_WDINT       = $0008;
  IO1388_VALUE       = $0010;
  IO1388_FIFOOV      = $0020;

(**********************************************************
 ***  Functions                                         ***
 **********************************************************)

(**********************************************************
 *** This function has to be called once at the begin of***
 *** the program!                                       ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_InitDriver                                      :Byte; stdcall;

(**********************************************************
 *** This function has to be called once at the end of  ***
 *** the program!                                       ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_DeInitDriver                                    :Byte; stdcall;

(**********************************************************
 *** This function returns the number of IO1388-Cards   ***
 *** installed on the PC                                ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** CardCount = Number of installed cards              ***
 **********************************************************)
function IO1388_GetCardCount     (var Anzahl:Byte)              :Byte; stdcall;

(**********************************************************
 *** This function returns the serial number of a card  ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** CardCount = Number of installed cards              ***
 **********************************************************)
function IO1388_GetCardNumber    (Card:Byte; var Number:LongInt):Byte; stdcall;

(**********************************************************
 *** This function returns the error code of the last   ***
 *** called DLL-function                                ***
 *** Return Parameter:                                  ***
 ***   Error-Code                                       ***
 **********************************************************)
function IO1388_GetLastError                                 :Integer; stdcall;

(**********************************************************
 *** This function sets the outputs                     ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = state for the outputs                    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_WriteOutputs     (Card:Byte; Value:LongInt)      :Byte; stdcall;

(**********************************************************
 *** This function rereads the outputs                  ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = state of the outputs                       ***
 **********************************************************)
function IO1388_ReadOutputs      (Card:Byte; var Value:LongInt)  :Byte; stdcall;

(**********************************************************
 *** This function reads the inputs                     ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = state of the inputs                        ***
 **********************************************************)
function IO1388_ReadInputs       (Card:Byte; var Value:LongInt)  :Byte; stdcall;

(**********************************************************
 *** This function reads the interrupt enables for the  ***
 *** rising edge of the inputs                          ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = interrupt enables for rising edge          ***
 **********************************************************)
function IO1388_ReadIntRise      (Card:Byte; var Value:LongInt)  :Byte; stdcall;

(**********************************************************
 *** This function sets the interrupt enables for the   ***
 *** rising edge for the inputs                         ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = interrupt enables for the rising edge    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_WriteIntRise     (Card:Byte; Value:LongInt)      :Byte; stdcall;

(**********************************************************
 *** This function reads the interrupt enables for the  ***
 *** falling edge of the inputs                         ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = interrupt enables for falling edge         ***
 **********************************************************)
function IO1388_ReadIntFall      (Card:Byte; var Value:LongInt)  :Byte; stdcall;

(**********************************************************
 *** This function sets the interrupt enables for the   ***
 *** falling edge for the inputs                        ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = interrupt enables for the falling edge   ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_WriteIntFall     (Card:Byte; Value: LongInt)     :Byte; stdcall;

(**********************************************************
 *** This function reads the timer/status register      ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = timer/status value                         ***
 **********************************************************)
function IO1388_ReadTimerStatus  (Card:Byte; var Value:LongInt)  :Byte; stdcall;

(**********************************************************
 *** This function sets the timer/status register       ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = new timer/status value                   ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_WriteTimerStatus (Card:Byte; Value: LongInt)     :Byte; stdcall;

(**********************************************************
 *** This function reads the watchdog-timer value       ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = watchdog-timer value                       ***
 **********************************************************)
function IO1388_ReadWdTimer      (Card:Byte; var Value:LongInt)  :Byte; stdcall;

(**********************************************************
 *** This function sets the watchdog-timer value        ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = new watchdog-timer value                 ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_WriteWdTimer     (Card:Byte; Value: LongInt)     :Byte; stdcall;

(**********************************************************
 *** This function reads the watchdog-output value      ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = watchdog-output value                      ***
 **********************************************************)
function IO1388_ReadWdValue      (Card:Byte; var Value:LongInt)  :Byte; stdcall;

(**********************************************************
 *** This function sets the watchdog-output value       ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = new watchdog-output value                ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_WriteWdValue     (Card:Byte; Value: LongInt)     :Byte; stdcall;

(**********************************************************
 *** This function starts interrupt handling. Interrupt-***
 *** enables has to be set by other functions.          ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_StartIRQ         (Card:Byte)                    :Byte; stdcall;

(**********************************************************
 *** This function stops interrupt handling. Interrupt- ***
 *** enables has to be set/reset by other functions.    ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************)
function IO1388_StopIRQ          (Card:Byte)                    :Byte; stdcall;

(**********************************************************
 *** This function reads the state of interrupt-handling***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = Flags                                      ***
 **********************************************************)
function IO1388_GetIRQStatus     (Card:Byte; var Value:LongInt)  :Byte; stdcall;

(**********************************************************
 *** This function reads the interrupt-handled inputs   ***
 *** blockwise.                                         ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  buffer = array where inputs will be saved         ***
 ***  buffersize = size in LongInts, not Bytes!         ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 ***     n = number of input-values copied to array     ***
 **********************************************************)

 (* Call: x := IO1388_GetIRQInputs (CardNr,Addr(buffer[1]),buffersize,n);   *)
function IO1388_GetIRQInputs     (Card:Byte; buffer:pLongInt; buffersize:LongInt; var n:LongInt):Byte; stdcall;



(**********************************************************
 *** Include all DLL-functions                          ***
 **********************************************************)
implementation

function IO1388_InitDriver                                      :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_InitDriver@0';
function IO1388_DeInitDriver                                    :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_DeInitDriver@0';
function IO1388_GetCardCount     (var Anzahl:Byte)              :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_GetCardCount@4';
function IO1388_GetCardNumber    (Card:Byte; var Number:LongInt):Byte; stdcall; external 'IO1388.DLL' name '_IO1388_GetCardNumber@8';
function IO1388_GetLastError                                 :Integer; stdcall; external 'IO1388.DLL' name '_IO1388_GetLastError@0';
function IO1388_WriteOutputs     (Card:Byte; Value: LongInt)     :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_WriteOutputs@8';
function IO1388_ReadOutputs      (Card:Byte; var Value:LongInt)  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_ReadOutputs@8';
function IO1388_ReadInputs       (Card:Byte; var Value:LongInt)  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_ReadInputs@8';
function IO1388_ReadIntRise      (Card:Byte; var Value:LongInt)  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_ReadIntRise@8';
function IO1388_WriteIntRise     (Card:Byte; Value: LongInt)     :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_WriteIntRise@8';
function IO1388_ReadIntFall      (Card:Byte; var Value:LongInt)  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_ReadIntFall@8';
function IO1388_WriteIntFall     (Card:Byte; Value: LongInt)     :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_WriteIntFall@8';
function IO1388_ReadTimerStatus  (Card:Byte; var Value:LongInt)  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_ReadTimerStatus@8';
function IO1388_WriteTimerStatus (Card:Byte; Value: LongInt)     :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_WriteTimerStatus@8';
function IO1388_ReadWdTimer      (Card:Byte; var Value:LongInt)  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_ReadWdTimer@8';
function IO1388_WriteWdTimer     (Card:Byte; Value: LongInt   )  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_WriteWdTimer@8';
function IO1388_ReadWdValue      (Card:Byte; var Value:LongInt)  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_ReadWdValue@8';
function IO1388_WriteWdValue     (Card:Byte; Value: LongInt)     :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_WriteWdValue@8';
function IO1388_StartIRQ         (Card:Byte)                    :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_StartIRQ@4';
function IO1388_StopIRQ          (Card:Byte)                    :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_StopIRQ@4';
function IO1388_GetIRQStatus     (Card:Byte; var Value:LongInt)  :Byte; stdcall; external 'IO1388.DLL' name '_IO1388_GetIRQStatus@8';
function IO1388_GetIRQInputs     (Card:Byte; buffer:pLongInt; buffersize:LongInt; var n:LongInt):Byte; stdcall; external 'IO1388.DLL' name '_IO1388_GetIRQInputs@16';

end.
