/**********************************************************
 ***       Header-File for IO 1388_x64-DLL              ***
 **********************************************************
 ***       (c) 2001 by ERMA - Electronic GmbH           ***
 **********************************************************
 ***  Programmed: 16.08.2010 Frank Jessen Dipl.Ing.(FH) ***
 **********************************************************/
#ifndef _IO1388_X64_
#define _IO1388_X64_

/**********************************************************
 ***  Error messages                                    ***
 **********************************************************/
#define IO1388_ERR_OK            0
#define IO1388_ERR_ALREADYOPEN   1
#define IO1388_ERR_NOTOPEN       2
#define IO1388_ERR_NOCARD        3
#define IO1388_ERR_NOADDRESS     4
#define IO1388_ERR_NOVALUE       5
#define IO1388_ERR_WRONGMODE     6
#define IO1388_ERR_VXDNOTFOUND   7
#define IO1388_ERR_DRVNOTFOUND   7
#define IO1388_ERR_INTERNALERROR 8
#define IO1388_ERR_FUNCDISABLED  9
#define IO1388_ERR_WRONGVALUE    10
#define IO1388_ERR_DEVICERUNNING 11
#define IO1388_ERR_DEVICESTOPPED 12

/**********************************************************
 ***  Flags                                             ***
 **********************************************************/
#define IO1388_RUNNING     0x0001
#define IO1388_IOINT       0x0002	
#define IO1388_TMINT       0x0004	
#define IO1388_WDINT       0x0008	
#define IO1388_VALUE       0x0010
#define IO1388_FIFOOV      0x0020	

/**********************************************************
 ***  Functions                                         ***
 **********************************************************/
#ifdef __cplusplus
    extern "C" {
#endif

/**********************************************************
 *** This function has to be called once at the begin of***
 *** the program!                                       ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_InitDriver     (void);

/**********************************************************
 *** This function has to be called once at the end of  ***
 *** the program!                                       ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_DeInitDriver   (void);

/**********************************************************
 *** This function returns the number of IO1388-Cards   ***
 *** installed on the PC                                ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** CardCount = Number of installed cards              ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_GetCardCount   (unsigned char  *Anzahl);

/**********************************************************
 *** This function returns the serial number of a card  ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** CardCount = Number of installed cards              ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_GetCardNumber  (unsigned char Card, UINT32 *Number);

/**********************************************************
 *** This function returns the error code of the last   ***
 *** called DLL-function                                ***
 *** Return Parameter:                                  ***
 ***   Error-Code                                       ***
 **********************************************************/
__declspec (dllimport) int  __stdcall IO1388_GetLastError  (void);

/**********************************************************
 *** This function sets the outputs                     ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = state for the outputs                    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_WriteOutputs     (unsigned char Card, UINT32   Wert);

/**********************************************************
 *** This function rereads the outputs                  ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = state of the outputs                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_ReadOutputs      (unsigned char Card, UINT32  *Wert);

/**********************************************************
 *** This function reads the inputs                     ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = state of the inputs                        ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_ReadInputs       (unsigned char Card, UINT32  *Wert);

/**********************************************************
 *** This function reads the interrupt enables for the  ***
 *** rising edge of the inputs                          ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = interrupt enables for rising edge          ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_ReadIntRise      (unsigned char Card, UINT32  *Wert);

/**********************************************************
 *** This function sets the interrupt enables for the   ***
 *** rising edge for the inputs                         ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = interrupt enables for the rising edge    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_WriteIntRise     (unsigned char Card, UINT32   Wert);

/**********************************************************
 *** This function reads the interrupt enables for the  ***
 *** falling edge of the inputs                         ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = interrupt enables for falling edge         ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_ReadIntFall      (unsigned char Card, UINT32  *Wert);

/**********************************************************
 *** This function sets the interrupt enables for the   ***
 *** falling edge for the inputs                        ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = interrupt enables for the falling edge   ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_WriteIntFall     (unsigned char Card, UINT32   Wert);

/**********************************************************
 *** This function reads the timer/status register      ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = timer/status value                         ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_ReadTimerStatus  (unsigned char Card, UINT32  *Wert);

/**********************************************************
 *** This function sets the timer/status register       ***
 *** Input Parameter:                                   ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = new timer/status value                   ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_WriteTimerStatus (unsigned char Card, UINT32   Wert);

/**********************************************************
 *** This function reads the watchdog-timer value       ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = watchdog-timer value                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_ReadWdTimer      (unsigned char Card, UINT32  *Wert);

/**********************************************************
 *** This function sets the watchdog-timer value        ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = new watchdog-timer value                 ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_WriteWdTimer     (unsigned char Card, UINT32   Wert);

/**********************************************************
 *** This function reads the watchdog-output value      ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = watchdog-output value                      ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_ReadWdValue      (unsigned char Card, UINT32  *Wert);

/**********************************************************
 *** This function sets the watchdog-output value       ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  Value  = new watchdog-output value                ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_WriteWdValue     (unsigned char Card, UINT32   Wert);

/**********************************************************
 *** This function starts interrupt handling. Interrupt-***
 *** enables has to be set by other functions.          ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_StartIRQ         (unsigned char Card);

/**********************************************************
 *** This function stops interrupt handling. Interrupt- ***
 *** enables has to be set/reset by other functions.    ***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_StopIRQ          (unsigned char Card);

/**********************************************************
 *** This function reads the state of interrupt-handling***
 ***  CardNr = zero-based number of the desired card    ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 *** Value = Flags                                      ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_GetIRQStatus     (unsigned char Card, UINT32  *Wert);

/**********************************************************
 *** This function reads the interrupt-handled inputs   ***
 *** blockwise.                                         ***
 ***  CardNr = zero-based number of the desired card    ***
 ***  buffer = array where inputs will be saved         ***
 ***  buffersize = size in INT32Ints, not Bytes!         ***
 *** Return Parameter:                                  ***
 ***     0 = Error                                      ***
 ***   255 = O.K.                                       ***
 ***     n = number of input-values copied to array     ***
 **********************************************************/
__declspec (dllimport) char __stdcall IO1388_GetIRQInputs     (unsigned char Card, INT32 (*buffer)[], UINT32 buffersize, UINT32 *n);


#ifdef __cplusplus
    }
#endif
#endif
